@@ -8,6 +8,7 @@ import io
 import json
 import multiprocessing
 import os
+import re
 import socket
 import subprocess
 import sys
@@ -75,19 +76,20 @@ class Runnable:
     A instance of :class:`BaseRunner` is the entity that will actually
     execute a runnable.
     """
-    def __init__(self, kind, uri, *args, **kwargs):
+    def __init__(self, kind, uri, *args, config=None, **kwargs):
         self.kind = kind
         self.uri = uri
+        self.config = config or {}
         self.args = args
         self.tags = kwargs.pop('tags', None)
         self.requirements = kwargs.pop('requirements', None)
         self.kwargs = kwargs
 
     def __repr__(self):
-        fmt = ('<Runnable kind="{}" uri="{}" args="{}" kwargs="{}" tags="{}" '
-               'requirements="{}">')
-        return fmt.format(self.kind, self.uri, self.args, self.kwargs,
-                          self.tags, self.requirements)
+        fmt = ('<Runnable kind="{}" uri="{}" config="{}" args="{}" '
+               'kwargs="{}" tags="{}" requirements="{}">')
+        return fmt.format(self.kind, self.uri, self.config, self.args,
+                          self.kwargs, self.tags, self.requirements)
 
     @classmethod
     def from_args(cls, args):
@@ -96,6 +98,7 @@ class Runnable:
         return cls(args.get('kind'),
                    args.get('uri'),
                    *decoded_args,
+                   config=json.loads(args.get('config', '{}')),
                    **_key_val_args_to_kwargs(args.get('kwargs', [])))
 
     @classmethod
@@ -112,6 +115,7 @@ class Runnable:
         return cls(recipe.get('kind'),
                    recipe.get('uri'),
                    *recipe.get('args', ()),
+                   config=recipe.get('config', {}),
                    **recipe.get('kwargs', {}))
 
     def get_command_args(self):
@@ -129,6 +133,10 @@ class Runnable:
             args.append('-u')
             args.append(self.uri)
 
+        if self.config is not None:
+            args.append('-c')
+            args.append(json.dumps(self.config))
+
         for arg in self.args:
             args.append('-a')
             if arg.startswith('-'):
@@ -157,6 +165,7 @@ class Runnable:
         recipe = collections.OrderedDict(kind=self.kind)
         if self.uri is not None:
             recipe['uri'] = self.uri
+        recipe['config'] = self.config
         if self.args is not None:
             recipe['args'] = self.args
         kwargs = self.kwargs.copy()
@@ -244,9 +253,9 @@ class Runnable:
         # runner convention within the avocado.core namespace dir.
         # Looking for the file only avoids an attempt to load the module
         # and should be a lot faster
-        core_dir = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))
-        module_name = self.kind.replace('-', '_')
-        module_filename = 'nrunner_%s.py' % module_name
+        core_dir = os.path.dirname(os.path.abspath(__file__))
+        module_name = "nrunner_%s" % self.kind.replace('-', '_')
+        module_filename = '%s.py' % module_name
         if os.path.exists(os.path.join(core_dir, module_filename)):
             full_module_name = 'avocado.core.%s' % module_name
             candidate_cmd = [sys.executable, '-m', full_module_name]
@@ -418,12 +427,19 @@ class ExecTestRunner(ExecRunner):
     Runnable attributes usage is identical to :class:`ExecRunner`
     """
     def run(self):
+        # Since Runners are standalone, and could be executed on a remote
+        # machine in an "isolated" way, there is no way to assume a default
+        # value, at this moment.
+        skip_codes = self.runnable.config.get('runner.exectest.exitcodes.skip',
+                                              [])
         for most_current_execution_state in super(ExecTestRunner, self).run():
-            if 'returncode' in most_current_execution_state:
-                if most_current_execution_state['returncode'] == 0:
-                    most_current_execution_state['result'] = 'pass'
-                else:
-                    most_current_execution_state['result'] = 'fail'
+            returncode = most_current_execution_state.get('returncode')
+            if returncode in skip_codes:
+                most_current_execution_state['result'] = 'skip'
+            elif returncode == 0:
+                most_current_execution_state['result'] = 'pass'
+            else:
+                most_current_execution_state['result'] = 'fail'
             yield most_current_execution_state
 
 
@@ -675,7 +691,8 @@ class Task:
         runnable_recipe = recipe.get('runnable')
         runnable = Runnable(runnable_recipe.get('kind'),
                             runnable_recipe.get('uri'),
-                            *runnable_recipe.get('args', ()))
+                            *runnable_recipe.get('args', ()),
+                            config=runnable_recipe.get('config'))
         status_uris = recipe.get('status_uris')
         return cls(identifier, runnable, status_uris, known_runners)
 
@@ -711,6 +728,19 @@ class Task:
             yield status
 
 
+def _get_kind_options_from_executable_name():
+    executable_name = os.path.basename(sys.argv[0])
+    match = re.match(r'^avocado\-runner\-(.+)$', executable_name)
+    options = {'type': str, 'help': 'Kind of runnable'}
+    if match:
+        options['required'] = False
+        options['default'] = match.group(1)
+        options['help'] += ', defaults to "%(default)s"'
+    else:
+        options['required'] = True
+    return options
+
+
 class BaseRunnerApp:
     '''
     Helper base class for common runner application behavior
@@ -731,11 +761,14 @@ class BaseRunnerApp:
     #: The command line arguments to the "runnable-run" command
     CMD_RUNNABLE_RUN_ARGS = (
         (('-k', '--kind'),
-         {'type': str, 'required': True, 'help': 'Kind of runnable'}),
+         _get_kind_options_from_executable_name()),
 
         (('-u', '--uri'),
          {'type': str, 'default': None, 'help': 'URI of runnable'}),
 
+        (('-c', '--config'),
+         {'type': str, 'default': '{}', 'help': 'A config JSON data'}),
+
         (('-a', '--arg'),
          {'action': 'append', 'default': [],
           'help': 'Simple arguments to runnable'}),
