@@ -149,7 +149,7 @@ class NetworkInterface:
                  otherwise will return False.
         """
         try:
-            if self._get_interface_details().get('flags')[2] == 'UP':
+            if 'UP' in self._get_interface_details().get('flags'):
                 return True
         except (NWException, IndexError):
             raise NWException("Could not get Administrative link state.")
@@ -162,7 +162,7 @@ class NetworkInterface:
                  otherwise will return False.
         """
         try:
-            if self._get_interface_details().get('flags')[3] == 'LOWER_UP':
+            if 'LOWER_UP' in self._get_interface_details().get('flags'):
                 return True
         except (NWException, IndexError):
             raise NWException("Could not get operational link state.")
@@ -288,17 +288,19 @@ class NetworkInterface:
             msg = 'Distro not supported by API. Could not save ipaddr.'
             raise NWException(msg)
 
-        self._write_to_file("{}/{}".format(path, filename),
-                            {'TYPE': self.if_type,
-                             'BOOTPROTO': 'none',
-                             'NAME': self.name,
-                             'DEVICE': self.name,
-                             'ONBOOT': 'yes',
-                             'IPADDR': ipaddr,
-                             'NETMASK': netmask,
-                             'IPV6INIT': 'yes',
-                             'IPV6_AUTOCONF': 'yes',
-                             'IPV6_DEFROUTE': 'yes'})
+        ifcfg_dict = {'TYPE': self.if_type,
+                      'BOOTPROTO': 'none',
+                      'NAME': self.name,
+                      'DEVICE': self.name,
+                      'ONBOOT': 'yes',
+                      'IPADDR': ipaddr,
+                      'NETMASK': netmask,
+                      'IPV6INIT': 'yes',
+                      'IPV6_AUTOCONF': 'yes',
+                      'IPV6_DEFROUTE': 'yes'}
+        if current_distro.name == 'SuSE':
+            ifcfg_dict.pop('BOOTPROTO')
+        self._write_to_file("{}/{}".format(path, filename), ifcfg_dict)
 
     def set_mtu(self, mtu, timeout=30):
         """Sets a new MTU value to this interface.
@@ -338,6 +340,22 @@ class NetworkInterface:
             msg = 'Failed to remove ipaddr. {}'.format(ex)
             raise NWException(msg)
 
+    def remove_link(self):
+        """Deletes virtual interface link.
+
+        This method will try to delete the virtual device link and the
+        interface will no more be listed with 'ip a' and if fails it
+        will raise a NWException. Be careful, you can lost connection.
+
+        You must have sudo permissions to run this method on a host.
+        """
+        cmd = 'ip link del dev {}'.format(self.name)
+        try:
+            run_command(cmd, self.host, sudo=True)
+        except Exception as ex:
+            msg = 'Failed to delete link. {}'.format(ex)
+            raise NWException(msg)
+
     def restore_from_backup(self):
         """Revert interface file from backup.
 
