@@ -6,8 +6,7 @@ from avocado.core.job import Job
 from avocado.core.suite import TestSuite
 
 config = {'run.references': ['examples/tests/passtest.py:PassTest.test'],
-          'job.run.result.html.enabled': 'on',
-          'run.open_browser': True}
+          'job.run.result.html.enabled': 'on'}
 
 suite = TestSuite.from_config(config)
 with Job(config, [suite]) as j:
