@@ -17,7 +17,8 @@ class Test(TestCaseTmpDir):
         super(Test, self).setUp()
         self.base_config = {'core.show': ['none'],
                             'run.results_dir': self.tmpdir.name,
-                            'run.references': ['examples/tests/passtest.py']}
+                            'run.references': ['examples/tests/passtest.py'],
+                            'run.keep_tmp': True}
 
     def test_job_run_result_json_enabled(self):
         self.base_config['job.run.result.json.enabled'] = 'on'
